<?php
/*
Plugin Name: Agechecked.org for wordpress 
Description: This plugin is used to perform age checks on customers during the WooCommerce checkout process.
Version: 1.1
Author: AgeChecked
Author URI: http://www.agechecked.com
License: GPLv2 or later
License URI: http://www.gnu.org/licenses/gpl-2.0.html
*/


add_action( 'admin_menu', 'agecheck_add_admin_menu' );
add_action( 'admin_init', 'agecheck_settings_init' );
add_action('wp_enqueue_scripts', 'agechecked_enqueue_scripts');


function agecheck_add_admin_menu(  ) { 
	add_menu_page( 'Agechecked', 'Agechecked', 'manage_options', 'agechecked_for_wordpress', 'agecheck_options_page' );
}


function agecheck_settings_init(  ) { 

	register_setting( 'pluginPage', 'agecheck_settings' );

	add_settings_section(
		'agecheck_pluginPage_section', 
		__( 'AgeChecked Settings', 'agecheck' ), 
		'agecheck_settings_section_callback', 
		'pluginPage'
	);

	add_settings_field( 
		'agechecked_settings_enabled', 
		__( 'Enable/Disable', 'agecheck' ), 
		'agechecked_settings_enabled_render', 
		'pluginPage', 
		'agecheck_pluginPage_section' 
	);

	add_settings_field( 
		'agechecked_settings_url', 
		__( 'API URL', 'agecheck' ), 
		'agechecked_settings_url_render', 
		'pluginPage', 
		'agecheck_pluginPage_section' 
	);

	add_settings_field( 
		'agechecked_settings_public_key', 
		__( 'Public Key', 'agecheck' ), 
		'agechecked_settings_public_key_render', 
		'pluginPage', 
		'agecheck_pluginPage_section' 
	);

	add_settings_field( 
		'agechecked_settings_private_key', 
		__( 'Private Key', 'agecheck' ), 
		'agechecked_settings_private_key_render', 
		'pluginPage', 
		'agecheck_pluginPage_section' 
	);

	add_settings_field( 
		'agechecked_settings_not_age_check_page', 
		__( 'Failover Page URL', 'agecheck' ), 
		'agechecked_settings_not_age_check_page_render', 
		'pluginPage', 
		'agecheck_pluginPage_section' 
	);	

}


function agechecked_settings_enabled_render(  ) { 

	$options = get_option( 'agecheck_settings' );
	?>
	<input type='checkbox' name='agecheck_settings[agechecked_settings_enabled]' <?php checked( $options['agechecked_settings_enabled'], 1 ); ?> value='1'>Enable age checks 
	<?php

}


function agechecked_settings_url_render(  ) { 

	$options = get_option( 'agecheck_settings' );
	?>
	<input class="regular-text"  type='text' name='agecheck_settings[agechecked_settings_url]' value='<?php echo $options['agechecked_settings_url']; ?>'>
	<?php

}


function agechecked_settings_public_key_render(  ) { 

	$options = get_option( 'agecheck_settings' );
	?>
	<input class="regular-text"  type='text' name='agecheck_settings[agechecked_settings_public_key]' value='<?php echo $options['agechecked_settings_public_key']; ?>'>
	<?php

}


function agechecked_settings_private_key_render(  ) { 

	$options = get_option( 'agecheck_settings' );
	?>
	<input class="regular-text" type='text' name='agecheck_settings[agechecked_settings_private_key]' value='<?php echo $options['agechecked_settings_private_key']; ?>'>
	<?php

}


function agechecked_settings_not_age_check_page_render(  ) { 

	$options = get_option( 'agecheck_settings' );
	?>
	<input class="regular-text" type='text' name='agecheck_settings[agechecked_settings_not_age_check_page]' value='<?php echo $options['agechecked_settings_not_age_check_page']; ?>'>
	<?php

}


function agecheck_settings_section_callback(  ) { 

	//echo __( 'This section description', 'agecheck' );
checks();
}

 function checks() {
	 	$options = get_option( 'agecheck_settings' );
	 
			if ( checked( $options['agechecked_settings_enabled'], 0 ) ) {
				return false;
			}

			// PHP Version
			if ( version_compare( phpversion(), '5.3', '<' ) ) {
				echo '<div class="error"><p>' . sprintf( __( 'AgeChecked Error: AgeChecked requires PHP 5.3 and above. You are using version %s.', 'agechecked' ), phpversion() ) . '</p></div>';
				return false;
			}
			
			// Check required fields
			if (!$options['agechecked_settings_url']) {
				echo '<div class="error"><p>' . __( 'AgeChecked Error: Please enter your API URL', 'agechecked' ) . '</p></div>';
				return false;
			}
			
			// Check required fields
			if ( ! $options['agechecked_settings_public_key'] || ! $options['agechecked_settings_private_key'] ) {
				echo '<div class="error"><p>' . __( 'AgeChecked Error: Please enter your public and private keys', 'agechecked' ) . '</p></div>';
				return false;
			}
			
			return true;
		}


function agecheck_options_page() { 
	?>
	<form action='options.php' method='post'>
		<?php
		settings_fields( 'pluginPage' );
		do_settings_sections( 'pluginPage' );
		submit_button();
		?>
	</form>
	<?php
}

function agechecked_enqueue_scripts()
{
	$options = get_option( 'agecheck_settings' );
	if(checked( $options['agechecked_settings_enabled'], 0 ) || !checks()) return false;
	
	$public_key = $options['agechecked_settings_public_key'];
	$url        = $options['agechecked_settings_url'];
	
	// Enqueues required JS files
	wp_enqueue_script('wp_cookie', plugins_url('agecheck/assets/js/jquery.cookie.js'), array('jquery'));
	$url = add_query_arg(array('merchantkey' => $public_key, 'version' => '1.0'), $url . '/jsapi/getjavascript');
	wp_enqueue_script('wp_agechecked_js', $url, array('jquery'), null);
	wp_enqueue_style('wp_agechecked_style', plugins_url('agecheck/assets/css/style.css'), array());
}

add_action( 'get_footer', 'agechecked_ui' );

//Loading AgeChecked UI on website loading
function agechecked_ui()
{
	$options = get_option( 'agecheck_settings' );
	if($options['agechecked_settings_not_age_check_page'] != '' ){
	$not_age_check_page = $options['agechecked_settings_not_age_check_page'];
	}else{
		$not_age_check_page = get_option('siteurl');
	}
	if(checked( $options['agechecked_settings_enabled'], 0 ) || !checks()) return false;
		
	?>
	<script>
	function handlereturn(d) {
	         Agechecked.API.modalclose();
	         var msg = JSON.parse(d.data);
             if (msg.status == 6 || msg.status == 7 || msg.status == 12) 
                { 
				   jQuery.cookie('agechecked_agecheckid', msg.agecheckid);
				   jQuery.cookie('agechecked_ageverifiedid', msg.ageverifiedid);
				}else{ 
					//window.open ('<?php //echo $not_age_check_page; ?>','_self',false);
				}
        }

	if(!jQuery.cookie('agechecked_agecheckid') && !jQuery.cookie('agechecked_ageverifiedid')){
         
		 if (typeof Agechecked !== "undefined" && Agechecked.API.isloaded()) {
	         Agechecked.API.registerreturn(handlereturn);
	         Agechecked.API.createagecheckjson( { mode: "javascript",avtype: "agechecked"}).done(function (json) { Agechecked.API.modalopen(json.agecheckurl); }); 
		}else{
		  alert("agechecked.com service not loaded.");
		  window.open ('<?php echo $not_age_check_page; ?>','_self',false); 
		}	 
	}	
	
	</script>
	<?php
}
?>